flytrap package - flytrap 0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# flytrap package

## Submodules

## flytrap.app module

flytrap.app.create_app(target_url: Optional[str] = None, port=8080, ngrok_token: Optional[str] = None, use_ngrok=False, speed_test=True, template_folder='./templates', static_folder='./static')

flytrap.app.gen_session_id() → str

flytrap.app.get_request_data()

flytrap.app.init_routes(app: flask.app.Flask)

flytrap.app.init_webhooks(base_url: str)

## flytrap.cli module

flytrap.cli.base(target_url: str, ngrok_token: typing.Optional[str] = <typer.models.OptionInfo object>, ngrok: bool = True, speed_test: bool = False, port: int = 8080)

## flytrap.sessions module

class flytrap.sessions.SessionBD(session_id: str)

  Bases: `object`

  get() → dict
  read() → dict
  set(data)
  update(data: dict)
  write(data)

flytrap.sessions.nested_update(d, u)

## flytrap.short_url module

## flytrap.utils module

## Module contents

Package for My Awesome Project